﻿using System;
using System.Windows.Forms;
using GTA;

namespace TestScriptCS {


   // ### get 10000 bucks each time you press M ###
   public class BasicKeyExample : Script {

      // KeyDown returns the pressed key.
      // but there is no need to check it when your script watches only this one key
      protected override void KeyDown(Keys key) {
         if (key == Keys.M) Player.Money += 10000;
      }

   }


   // ### This script will give you all advanced weapons and lots of ammo every 5 seconds ###
   public class BasicTickExample : Script {

      protected override void Startup() {
         Interval = 5000; // Interval is the time between two Ticks (in milliseconds)
      }

      protected override void Tick() {
         Game.DisableMaxAmmoLimit = true;
         Ped p = Player.Character;
         p.Weapons.BaseballBat.Ammo = 1;
         p.Weapons.Grenades.Ammo = 30000;
         p.Weapons.DesertEagle.Ammo = 30000;
         p.Weapons.Shotgun_Baretta.Ammo = 30000;
         p.Weapons.SMG_MP5.Ammo = 30000;
         p.Weapons.AssaultRifle_M4.Ammo = 30000;
         p.Weapons.SniperRifle_M40A1.Ammo = 30000;
         p.Weapons.RocketLauncher.Ammo = 30000;
      }

   }


   // ### Press the I key to become invincible against everything (besides falling damage) ###
   // ### Niko will still be affected by fire, explosions, etc. but won't die.             ###
   public class InvincibilityScript : Script {

      private bool bInvincible = false;
      private const int HEALTH_VALUE = 500000;

      protected override void Startup() {
         Interval = 250;
         BindKey(Keys.I, new KeyPressDelegate(ToggleInvincibility));
      }

      protected override void Tick() {
         if (bInvincible) {
            Player.Character.Health = HEALTH_VALUE;
            Player.Character.Armor = HEALTH_VALUE;
         }
      }

      public void ToggleInvincibility() {
         bInvincible = !bInvincible;
         Player.Character.ForceHelmet(bInvincible); // Show a helmet to visualize the invincibility
         if (bInvincible) {
            Player.MaxHealth = HEALTH_VALUE;
            Player.MaxArmor = HEALTH_VALUE;
            Player.Character.Health = HEALTH_VALUE;
            Player.Character.Armor = HEALTH_VALUE;
            Game.DisplayText("Invincible!");
         } else {
            Player.MaxHealth = 100;
            Player.MaxArmor = 100;
            Player.Character.Health = 100;
            Player.Character.Armor = 100;
            Game.DisplayText("NOT invincible!");
         }
      }

   }


   // ### Press O to keep the wanted level at zero ###
   public class PoliceScript : Script {

      private bool bNoPolice = false;

      protected override void Startup() {
         Interval = 250;
      }

      protected override void Tick() {
         if ((bNoPolice) && (Player.WantedLevel > 0))
            Player.WantedLevel = 0;
      }

      protected override void KeyDown(Keys key) {
         if (key != Keys.O) return;

         bNoPolice = !bNoPolice;
         if (bNoPolice) {
            Player.WantedLevel = 0;
            Game.WantedMultiplier = 0.0F;
            Game.DisplayText("Police will ignore you!");
         } else {
            Game.WantedMultiplier = 1.0F;
            Game.DisplayText("Police will NOT ignore you!");
         }
      }

   }


   // ### Press F7 to spawn a BANSHEE or F8 to change the player skin ###
   public class BindKeyExample : Script {

      private PedSkin SavedSkin;

      protected override void Startup() {
         SavedSkin = Player.Skin;
         BindKey(Keys.F7, new KeyPressDelegate(SpawnCar));
         BindKey(Keys.F8, new KeyPressDelegate(ChangeSkin));
      }

      public void SpawnCar() {
         World.CreateVehicle("BANSHEE", Player.Character.Position.Around(5.0F));
      }

      public void ChangeSkin() {
         if (Player.Model != "PLAYER") { // check if the player model has changed
            Player.Skin = SavedSkin;     // revert back to your original model and outfit
         } else {
            Game.ActivateMultiplayerModel(); // Activate the player skin selected for multiplayer mode
            //Player.Model = "M_Y_SWAT"      // use this instead of the line above to change the player model to the SWAT skin
         }
      }

   }


   // ### Type "Explode" into the console and you will explode...                   ###
   // ### Type "SpawnCar ?" (where ? is a number from 1 to 6) to get a new vehicle. ###
   // ### Call 123 on the phone to get an Annihilator helicopter.                   ###
   public class InfoAndBindExample : Script {

      protected override void Startup() {
         GeneralInfo = "Use console commands to make you explode, or spawn some vehicles. Call 123 on the phone to get an Annihilator helicopter.";
         BindConsoleCommand("Explode", new ConsoleCommandDelegate(ExplodeCommand), "- BOOOOOM!");
         BindConsoleCommand("SpawnCar", new ConsoleCommandDelegate(CarCommand), "[number] - Spawn an Infernus, Comet, SultanRS, Partiot, NRG 900 or Airtug");
         BindPhoneNumber("123", new PhoneDialDelegate(SpawnAnnihilator));
      }

      public void ExplodeCommand(ParameterCollection Parameter) {
         World.AddExplosion(Player.Character.Position);
      }

      public void SpawnAnnihilator() {
         Vehicle v = World.CreateVehicle("ANNIHILATOR", Player.Character.Position.Around(5.0F));
         v.NoLongerNeeded(); // Call this to make sure that the game will NOT keep the vehicle forever
      }

      public void CarCommand(ParameterCollection Parameter) {
         String CarType;
         switch (Parameter.ToInteger(0)) { // convert the first parameter (0) into an integer value
            case 1: CarType = "INFERNUS"; break;
            case 2: CarType = "COMET"; break;
            case 3: CarType = "SULTANRS"; break;
            case 4: CarType = "PATRIOT"; break;
            case 5: CarType = "NRG900"; break;
            default: CarType = "AIRTUG"; break;
         }
         Vehicle v = World.CreateVehicle(CarType, Player.Character.Position.Around(5.0F));
         v.NoLongerNeeded(); // Call this to make sure that the game will NOT keep the vehicle forever
      }

   }


   // ### Shows how to use PerFrameDrawing to draw graphical elements to the screen.         ###
   // ### Hold down the NumPad0 key in game and two blue boxes with red numbers will appear. ###
   public class DrawingExample : Script {

      private Font myfont;
      private System.Drawing.Color boxColor = System.Drawing.Color.FromArgb(127, 0, 0, 255);

      protected override void Startup() {
         myfont = new Font();
         myfont.Alignment = TextAlignment.Centered;
         myfont.Color = System.Drawing.Color.Red;
         myfont.Height = 0.15F;
         myfont.Scaling = FontScaling.ScreenUnits;
      }

      protected override void PerFrameDrawing(GTA.Graphics Graphics) {
         if (isKeyPressed(Keys.NumPad0)) {
            Graphics.DrawRectangle(0.25F, 0.25F, 0.2F, 0.2F, boxColor);
            Graphics.DrawText(0.25F, 0.15F, "1", myfont);

            Graphics.DrawCurvedWindow(0.75F, 0.75F, 0.2F, 0.2F, 224);
            Graphics.DrawText(0.75F, 0.65F, "2", myfont);

            // There are also some 3D objects that are drawn in PerFrameDrawing
            Graphics.DrawLight(Player.Character.GetOffsetPosition(new Vector3(-3.0F, 4.0F, 0.0F)), System.Drawing.Color.Green, 3.0F, 100.0F);
            Graphics.DrawCheckpoint(Player.Character.GetOffsetPosition(new Vector3(3.0F, 4.0F, 0.0F)).ToGround(), 3.0F, System.Drawing.Color.Blue);
         }
      }

   }


   // ### Spawns a Ped when pressing K, which attacks you for 5 sec, flees for 5 sec and then dies  ###
   public class TaskSequenceExample : Script {

      private TaskSequence FleeTask;

      protected override void Startup() {
         // Add tasks to the TaskSequence
         FleeTask = new TaskSequence();
         FleeTask.AddTask.SwapWeapon(Weapon.Handgun_Glock);
         FleeTask.AddTask.FightAgainst(Player, 5000);
         FleeTask.AddTask.FleeFromChar(Player, false, 5000);
         FleeTask.AddTask.Die();
      }

      protected override void KeyDown(Keys key) {
         if (key != Keys.K) return;

         Ped p = World.CreatePed(Player.Character.Position.Around(3.0F));
         p.CurrentRoom = Player.Character.CurrentRoom;
         p.Weapons.Glock.Ammo = 1000;
         p.Task.PerformSequence(FleeTask);
      }

   }


   // ### Press Z and a nearby ped will start walking towards you like a zombie  ###
   public class EuphoriaExample : Script {

      private Ped Zombie;

      protected override void Startup() {
         Interval = 250;
         GeneralInfo = "Press Z and a nearby ped will start walking towards you like a zombie!";
         BindKey(Keys.Z, new KeyPressDelegate(DoTheZombie));
      }

      public void DoTheZombie() {
         if (Exists(Zombie)) {
            Zombie.isRagdoll = false;
            Zombie = null;
            return;
         }

         Zombie = World.GetClosestPed(Player.Character.Position, 10.0F);
         if (!Exists(Zombie)) return;

         Game.DisplayText("ZOMBIES!!!");
         Zombie.Euphoria.BodyBalance.Start(-1);
      }

      protected override void Tick() {
         if (!Exists(Zombie)) {
            Zombie = null;
            return;
         }
         if (Zombie.isGettingUp) return; // wait until the zombie is standing
         if (!Zombie.isRagdoll) Zombie.Euphoria.BodyBalance.Start(-1);
         if (!Zombie.Euphoria.BodyBalance.isBalanced) { // get up again when fallen to the ground
            Zombie.isRagdoll = false;
            return;
         }

         Zombie.Euphoria.LeanToPosition.Amount = 1.0F;
         Zombie.Euphoria.LeanToPosition.ApplyAsForce = true;
         Zombie.Euphoria.LeanToPosition.Position = Player.Character.Position;
         Zombie.Euphoria.LeanToPosition.Start();
      }

   }


   // ### Uses native calls to get the name of the current vehicle when pressing L  ###
   public class NativeCallExample : Script {

      protected override void KeyDown(Keys key) {
         if (key != Keys.L) return;

         GTA.Native.Pointer PedPointer = typeof(Ped);
         GTA.Native.Function.Call("GET_PLAYER_CHAR", Player, PedPointer);
         Ped PlayerChar = PedPointer;

         if (!GTA.Native.Function.Call<bool>("IS_CHAR_IN_ANY_CAR", PlayerChar)) {
            Game.DisplayText("Not in a car!");
            return;
         }

         GTA.Native.Pointer CarPointer = typeof(Vehicle);
         GTA.Native.Function.Call("GET_CAR_CHAR_IS_USING", PlayerChar, CarPointer);

         GTA.Native.Pointer ModelPointer = typeof(Model);
         GTA.Native.Function.Call("GET_CAR_MODEL", CarPointer.ToInputParameter(), ModelPointer);

         String name = GTA.Native.Function.Call<String>("GET_DISPLAY_NAME_FROM_VEHICLE_MODEL", ModelPointer.ToInputParameter());

         Game.DisplayText("Car name: " + name);
      }

   }


   //// ### Syncronizes ingame time with the real time ###
   //public class TimeSyncExample : Script {

   //   int day;

   //   protected override void Startup() {
   //      Interval = 10000;
   //      DateTime real = DateTime.Now;
   //      day = real.DayOfYear;
   //      World.LockDayTime(real.Hour, real.Minute);
   //   }

   //   protected override void Tick() {
   //      DateTime real = DateTime.Now;
   //      if (day != real.DayOfYear) { // we can be sure that a new day begun in reality when the DayOfYear has changed
   //         day = real.DayOfYear;
   //         World.OneDayForward();
   //      }
   //      Weather w = World.Weather; // store and reset the weather, because LockDayTime changes it instantly
   //      World.LockDayTime(real.Hour, real.Minute);
   //      World.Weather = w;
   //   }

   //}


   //### Press J to smoke a spliff... Press J again or switch to a weapon to drop it. ###
   public class AnimationExample : Script {

      bool bSmoking = false;
      GTA.Object spliff;
      GTA.Timer timer = new GTA.Timer(); // the timer will always show the elapsed gametime since the last Start()

      AnimationSet anims = new AnimationSet("amb@smoking_spliff");
      AnimationFlags animflags = AnimationFlags.Unknown12 | AnimationFlags.Unknown11 | AnimationFlags.Unknown09;

      protected override void Startup() {
         Interval = 1000;
      }

      protected override void KeyDown(Keys key) {
         if (key != Keys.J) return;
         if (bSmoking)
            StopSmoking();
         else
            StartSmoking();
      }

      public void StartSmoking() {
         if (bSmoking) return;
         bSmoking = true;

         Player.Character.Weapons.Unarmed.Select();
         Player.Character.Animation.Play(anims, "create_spliff", animflags);
         Wait(1600);

         spliff = World.CreateObject(0xD130ADEF, Player.Character.Position);
         spliff.AttachToPed(Player.Character, Bone.RightHand, new Vector3(0.14F, 0.03F, 0.04F), new Vector3(2.21F, -0.12F, 0.0F));

         Player.Character.Animation.WaitUntilFinished(anims, "create_spliff");
         timer.Start();
      }

      public void StopSmoking() {
         if (!bSmoking) return;
         bSmoking = false;
         if (spliff == null) return;

         spliff.Detach();
         spliff.NoLongerNeeded();
      }

      protected override void Tick() {
         if (bSmoking) {
            if (Player.Character.Weapons.CurrentType != Weapon.Unarmed) {
               StopSmoking();
            } else if ((timer.ElapsedTime > 10000) && (Player.Character.isIdle)) {
               if (Player.Character.isInVehicle())
                  Player.Character.Task.PlayAnimation(anims, "partial_smoke_car", animflags);
               else
                  Player.Character.Task.PlayAnimation(anims, "partial_smoke", animflags);
               timer.Start();
            }
         }
      }

   }

}